| PyPI Release | Test Status | Code Coverage |
| ------------ | ----------- | ------------- |
| [![PyPI version](https://badge.fury.io/py/rms-vicar.svg)](https://badge.fury.io/py/rms-vicar) | [![Build status](https://img.shields.io/github/actions/workflow/status/SETI/rms-vicar/run-tests.yml?branch=master)](https://github.com/SETI/rms-vicar/actions) | [![Code coverage](https://img.shields.io/codecov/c/github/SETI/rms-vicar/main?logo=codecov)](https://codecov.io/gh/SETI/rms-vicar) |

# rms-vicar

PDS Ring-Moon Systems Node, SETI Institute

Supported versions: Python >= 3.7

Classes and methods to read and write VICAR image files.
